#
# spec file for package python-versioneer
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-versioneer
Version:        0.29
Release:        1.5
Summary:        VCS-based management of project version strings
License:        Unlicense
Group:          Development/Languages/Python
URL:            https://github.com/warner/python-versioneer
Source:         https://files.pythonhosted.org/packages/source/v/versioneer/versioneer-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module testsuite}
BuildRequires:  %{python_module tomli if %python-base < 3.11}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Versioneer is a tool to automatically update version strings (in
setup.py and the conventional ‘from PROJECT import _version’ pattern)
by asking the version control system about the current tree.

%package toml
Summary:        VCS-based management of project version strings [toml] extra
Requires:       python-versioneer = %{version}
Requires:       (python-tomli if python-base < 3.11)

%description toml
Versioneer is a tool to automatically update version strings (in
setup.py and the conventional ‘from PROJECT import _version’ pattern)
by asking the version control system about the current tree.

This package provides the [toml] extra

%prep
%setup -q -n versioneer-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand sed -i '1{/^#!/d}'  %{buildroot}%{$python_sitelib}/versioneer.py
%python_compileall
%python_clone -a %{buildroot}%{_bindir}/versioneer
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest -v test/test_file.py

%post
%python_install_alternative versioneer

%postun
%python_uninstall_alternative versioneer

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/versioneer.py*
%pycache_only %{python_sitelib}/__pycache__/versioneer*.pyc
%{python_sitelib}/versioneer-%{version}.dist-info
%python_alternative %{_bindir}/versioneer

%files %{python_files toml}
%doc README.md
%license LICENSE

%changelog
* Mon Sep 25 2023 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.29
  * FIX: Add error output when pyproject.toml is malformed
  * FIX: Add name to setup.py to work around a github dependency graph bug.
  * ENH: Add basic type information throughout project.
  * ENH: Detect pyproject.toml as project root (to support PDM).
  * MNT: Overwrite version file instead of delete/unlink.
  * MNT: Use https for the unlicense url.
* Fri May 26 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.28
  * FIX: handle unset versionfile_build in build_ext by @mgorny in
    [#347]
  * ENH: support built-in tomllib for Python 3.11+ by @mgorny in
    [#348]
- Release 0.27
  * FIX: Always bootstrap in setup.py to avoid incompatibility with
    old versioneer by @mgorny (#344)
  * FIX: Mixup between _egg_info and _sdist by @DimitriPapadopoulos
    (#342)
  * STY: Merge endswith checks by @DimitriPapadopoulos (#337)
  * STY: Useless inheritance from object by @DimitriPapadopoulos
    (#336)
- Provide [toml] extra as subpackage
* Mon May 22 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.24
  * MNT: Relicense to Unlicense by @effigies in #317
  * ENH: in verbose mode do not hide stderr of git rev-parse by @yarikoptic in #318
  * DOC: clarify upgrading to 0.23 doesn't require special actions by @sappelhoff in #321
  * ENH: Prepare for py2exe dropping distutils support by @effigies in #319
  * ENH: Allow versioneer to be used as a module in PEP-518 mode by @effigies in #294
* Sat Aug 28 2021 Matej Cepl <mcepl@suse.com>
- Make testing more verbose
* Thu Aug 26 2021 pgajdos@suse.com
- version update to 0.20
  Release 0.20 (13-Jul-2020)
  * Respect versionfile_source in __init__.py snippet (#241)
  * Add pep440-branch and pep440-post-branch styles (#164)
  * Stop testing deprecated easy_install, support left in for now (#237)
  * Use versionfile_build instead of versionfile_source where needed (#242)
  * Improve handling of refname edge cases (#229)
  * Clarify installation in docs (#235)
  * Play nicely with custom build_exts (#232)
  Release 0.19 (10-Nov-2020)
  * Drop support for Python < 3.6, test up to Python 3.9
  * Strip GPG signature information from date (#222)
  * Add bdist_ext cmdclass, to support native code extensions (#171)
  * Canonicalize pep440-pre style (#163)
  * Take arguments to get_cmdclass
- test the package a bit at least
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Jun  6 2018 jengelh@inai.de
- Ensure neutrality/accuracy of description
* Mon Feb 19 2018 arun@gmx.de
- initial version
